import React, { PropsWithChildren } from 'react';
import { noop } from '@highlight-ui/utils-commons';
import { SelectOption, SelectOptionProps, SelectOptionType } from '../types';
export declare type ListBoxProps = PropsWithChildren<{
    /**
     * ⚠️ _Consult a designer before using this prop, in most cases it shouldn't be used._
     * Determines whether or not a search input should be rendered in the select list. If set to true, the search input will only render if there are more than 7 options.
     */
    searchable?: boolean;
    /** Set to `true` when you have a `multi-select` scenario */
    multiple?: boolean;
    /** Highlights this text in the options list only when the Select is not searchable. */
    highlightedText?: string;
    searchInputValue: string;
    selectAllIsSelected: boolean;
    selectedOptionsWithValuesOnly: (string | number)[];
    listRef: React.Ref<HTMLUListElement>;
    onEscape: typeof noop;
    handleSelect: (option: SelectOption) => void;
    handleSelectAll: (selected: boolean) => void;
    optionType?: SelectOptionType;
}>;
export declare type ListBoxOptionProps = Omit<SelectOptionProps<SelectOption>, 'highlightedText' | 'onEscape' | 'onSelect' | 'selected' | 'optionStyle' | 'optionType'>;
declare type ListboxOption = React.FC<ListBoxOptionProps>;
declare const ListBox: {
    ({ children, searchable, highlightedText, multiple, searchInputValue, selectedOptionsWithValuesOnly, listRef, onEscape, handleSelect, optionType, }: ListBoxProps): JSX.Element;
    displayName: string;
    OptionGroup: ({ name, children }: import("../types").SelectOptionGroupProps) => JSX.Element;
    Option: ListboxOption;
};
export default ListBox;
